@@ -17,6 +17,8 @@
 #' @param styles Optional full path to CSS file to override default styles.
 #' @param focus_scenario_ids IDs of scenarios of special interest.
 #' @param format Format to generate (html, pdf, word).
+#' @param intermediates_dir Location for intermediate knit files.
+#' @param quiet TRUE to suppress printing of pandoc output.
 #' @param ... Any other parameters to pass straight to \code{rmarkdown::render}.
 #' @return Default return values of the \code{rmarkdown::render} function.
 #' @export
@@ -30,6 +32,8 @@ generate_report <- function(input_directory = "~/evaluator/inputs",
                             styles = NULL,
                             focus_scenario_ids = c(51, 12),
                             format = "html",
+                            intermediates_dir = tempdir(),
+                            quiet = TRUE,
                             ...) {
   if (!requireNamespace("psych", quietly = TRUE)) {
     stop("Install the psych package to generate reports.")
@@ -62,10 +66,12 @@ generate_report <- function(input_directory = "~/evaluator/inputs",
 
   rmarkdown::render(system.file("rmd", "analyze_risk.Rmd", package = "evaluator"),
                     output_file = output_file,
+                    intermediates_dir = intermediates_dir,
                     params = list(input_directory = input_directory,
                                   results_directory = results_directory,
                                   focus_scenario_ids = focus_scenario_ids),
                     output_format = out_format,
+                    quiet = quiet,
                     ...)
 }
 
@@ -81,6 +87,8 @@ generate_report <- function(input_directory = "~/evaluator/inputs",
 #' @param input_directory Location of input files.
 #' @param results_directory Location of simulation results.
 #' @param styles Optional full path to CSS file to override default styles.
+#' @param intermediates_dir Location for intermediate knit files.
+#' @param quiet TRUE to suppress printing of pandoc output.
 #' @param ... Any other parameters to pass straight to \code{rmarkdown::run}.
 #' @import dplyr
 #' @import ggplot2
@@ -92,7 +100,10 @@ generate_report <- function(input_directory = "~/evaluator/inputs",
 #' }
 explore_scenarios <- function(input_directory = "~/evaluator/inputs",
                               results_directory = "~/evaluator/results",
-                              styles = NULL, ...) {
+                              styles = NULL,
+                              intermediates_dir = tempdir(),
+                              quiet = TRUE,
+                              ...) {
   if (!requireNamespace("rmarkdown", quietly = TRUE)) {
     stop("Install the rmarkdown package to generate reports.")
   }
@@ -120,8 +131,10 @@ explore_scenarios <- function(input_directory = "~/evaluator/inputs",
                  render_args = list(
                    output_options =  list(css = styles, favicon = icon,
                                           logo = icon),
+                   intermediates_dir = intermediates_dir,
                    params = list(input_directory = input_directory,
-                               results_directory = results_directory)),
+                                 results_directory = results_directory),
+                   quiet = quiet),
                  ...)
   invisible(NULL)
 }
@@ -133,13 +146,16 @@ explore_scenarios <- function(input_directory = "~/evaluator/inputs",
 #' distribution of results, with high level summary statistics. As a demonstration
 #' application, only TEF+TC+DIFF+LM parameters may be entered.
 #'
+#' @param intermediates_dir Location for intermediate knit files.
+#' @param quiet TRUE to suppress printing of pandoc output.
 #' @return Invisible NULL
 #' @export
 #' @examples
 #' \dontrun{
 #' openfair_example()
 #' }
-openfair_example <- function() {
+openfair_example <- function(intermediates_dir = tempdir(),
+                             quiet = TRUE) {
   if (!requireNamespace("rmarkdown", quietly = TRUE)) {
     stop("Install the rmarkdown package to run the OpenFAIR demonstration application.")
   }
@@ -157,7 +173,9 @@ openfair_example <- function() {
                              package = "evaluator"),
                  render_args = list(output_options =  list(css = styles,
                                                            favicon = icon,
-                                                           logo = icon)
+                                                           logo = icon),
+                                    intermediates_dir = intermediates_dir,
+                                    quiet = quiet
                                     )
                  )
   invisible(NULL)
@@ -173,6 +191,8 @@ openfair_example <- function() {
 #' @param input_directory Location of input files
 #' @param results_directory Location of simulation results
 #' @param output_file Full path to the desired output file.
+#' @param intermediates_dir Location for intermediate knit files.
+#' @param quiet TRUE to suppress printing of pandoc output.
 #' @param ... Any other parameters to pass straight to \code{rmarkdown::render}
 #' @return Default return values of the \code{rmarkdown::render} function.
 #' @export
@@ -183,6 +203,8 @@ openfair_example <- function() {
 risk_dashboard <- function(input_directory = "~/evaluator/inputs",
                            results_directory = "~/evaluator/results",
                            output_file,
+                           intermediates_dir = tempdir(),
+                           quiet = TRUE,
                            ...) {
   if (!requireNamespace("rmarkdown", quietly = TRUE)) {
     stop("Install the rmarkdown package to generate the risk dashboard.")
@@ -199,7 +221,9 @@ risk_dashboard <- function(input_directory = "~/evaluator/inputs",
   rmarkdown::render(system.file("rmd", "risk_dashboard.Rmd", package = "evaluator"),
                     output_options =  list(css = styles, favicon = icon, logo = icon),
                     output_file = output_file,
+                    intermediates_dir = intermediates_dir,
                     params = list(input_directory = input_directory,
                                   results_directory = results_directory),
-                      ...)
+                    quiet = quiet,
+                    ...)
 }
